@@ -18,11 +18,4 @@ class BaseIntegration(ABC):
         pass
 
     def setup(self):
-        self.setup_trace()
-        self.setup_logging()
-
-    def setup_trace(self):
-        pass
-
-    def setup_logging(self):
         pass
